Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(480)

Unified Diff: chrome/browser/resources/tracing/profiling_view.js

Issue 7555005: Moving the contents of chrome://gpu Profiling to chrome://tracing. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 9 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/tracing/profiling_view.js
diff --git a/chrome/browser/resources/gpu_internals/profiling_view.js b/chrome/browser/resources/tracing/profiling_view.js
similarity index 94%
rename from chrome/browser/resources/gpu_internals/profiling_view.js
rename to chrome/browser/resources/tracing/profiling_view.js
index eb8a2e2e28a4b724b2e7b43e6a5d6bf8b17b804f..a4f13de13cf9635ff91f4c5d2aa38bdf99c3700b 100644
--- a/chrome/browser/resources/gpu_internals/profiling_view.js
+++ b/chrome/browser/resources/tracing/profiling_view.js
@@ -4,14 +4,14 @@
/**
* @fileoverview ProfilingView visualizes GPU_TRACE events using the
* gpu.Timeline component.
*/
-cr.define('gpu', function() {
+cr.define('tracing', function() {
/**
* ProfilingView
* @constructor
- * @extends {gpu.Tab}
+ * @extends {ui.TabPanel}
*/
ProfilingView = cr.ui.define(cr.ui.TabPanel);
@@ -99,7 +99,7 @@ cr.define('gpu', function() {
///////////////////////////////////////////////////////////////////////////
onSave_: function() {
- this.overlayEl_ = new gpu.Overlay();
+ this.overlayEl_ = new tracing.Overlay();
this.overlayEl_.className = 'profiling-overlay';
var labelEl = document.createElement('div');
@@ -124,7 +124,7 @@ cr.define('gpu', function() {
///////////////////////////////////////////////////////////////////////////
onLoad_: function() {
- this.overlayEl_ = new gpu.Overlay();
+ this.overlayEl_ = new tracing.Overlay();
this.overlayEl_.className = 'profiling-overlay';
var labelEl = document.createElement('div');
« no previous file with comments | « chrome/browser/resources/tracing/profiling_view.css ('k') | chrome/browser/resources/tracing/sorted_array_utils.js » ('j') | no next file with comments »
@@ -4,14 +4,14 @@
/**
- * @fileoverview ProfilingView visualizes GPU_TRACE events using the
- * gpu.Timeline component.
+ * @fileoverview ProfilingView visualizes TRACE_EVENT events using the
+ * tracing.Timeline component.
*/

Powered by Google App Engine
This is Rietveld 408576698